local MAJOR = "LibScriptableDisplayPNM-1.0"
local MINOR = 14

local PNM = LibStub:NewLibrary(MAJOR, MINOR)
if not PNM then return end
PluginUtils = LibStub("LibScriptableDisplayPluginUtils-1.0", true)
assert(PluginUtils, MAJOR .. " requires LibScriptableDisplayPluginUtils-1.0")
PluginColor = LibStub("LibScriptableDisplayPluginColor-1.0", true)
assert(PluginColor, MAJOR .. " requires LibScriptableDisplayPluginColor-1.0")
PluginColor = PluginColor:New({})

-- @name PNM:New
-- @return A new PNM object
function PNM:New(name, config, errorLevel)

	local obj = {}

	local image = PluginUtils.Split(config.pnm or "", "\n")
	local bitmap
	local grayimage
	local colorimage

	if image[1] == "P1" then
		bitmap = {type=image[1]}
		local wh = PluginUtils.Split(image[2], " ")
		local w = tonumber(wh[1])
		local h = tonumber(wh[2])
		obj.w = w
		obj.h = h
		for x = 0 , w - 1 do
			for y = 0, h - 1 do
				if image[x * h + y + 2] == "1" then
					bitmap[y * w + x] = true
				end
			end
		end
	elseif image[1] == "P2" then
		grayimage = {type=image[1]}
		
		local wh = PluginUtils.Split(image[3], " ")
		StarVisuals:Print("bleh", #wh, wh[1], wh[2])
		w = tonumber(wh[1])
		h = tonumber(wh[2])
		n = tonumber(image[4])
		StarVisuals:Print(w, h, n)
		obj.w = w
		obj.h = h
		obj.n = n
		for x = 0, w - 1 do
			for y = 0, h - 1 do
				grayimage[y * w + x] = tonumber(image[y * w + x + 4])
			end
		end
	elseif image[1] == "P3" then
		colorimage = {type=image[1]}
		local wh = PluginUtils.Split(image[3], " ")
		w = tonumber(string.trim(wh[1]))
		h = tonumber(string.trim(wh[2]))
		n = tonumber(string.trim(image[4]))
		obj.w = w
		obj.h = h
		obj.n = n
		for x = 0, w - 1 do
			for y = 0, h - 1 do
				local r = tonumber(string.trim(image[(y * w + x) * 3 + 4]))
				local g = tonumber(string.trim(image[(y * w + x) * 3 + 4 + 1]))
				local b = tonumber(string.trim(image[(y * w + x) * 3 + 4 + 2]))
				colorimage[y * h + x] = PluginColor.RGBA2Color(r, g, b)
			end
		end
	else
		return nil
	end
	obj.bitmap = bitmap
	obj.grayimage = grayimage
	obj.colorimage = colorimage
	
	obj.pixel = config.pixel
	obj.config = config
	
	return obj

end
